NegativeBinomial - LatentLego

Skip to content

# NegativeBinomial

### `latent.losses.NegativeBinomial`

Computes negative binomial loss between `y_true` and `y_pred` given a dispersion parameter (`theta`).

#### `__init__(self, theta, eps=1e-08, **kwargs)` `special`

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`theta` | `Union[tensorflow.python.framework.ops.Tensor, float]` | Positive float. Dispersion parameter. | required
`eps` | `float` | Positive float. Clipping value for numerical stability. | `1e-08`
`**kwargs` | `` | Other arguments passed to `keras.losses.Loss`. | `{}`